..
      Copyright 2011-2012 OpenStack Foundation
      All Rights Reserved.

      Licensed under the Apache License, Version 2.0 (the "License"); you may
      not use this file except in compliance with the License. You may obtain
      a copy of the License at

          http://www.apache.org/licenses/LICENSE-2.0

      Unless required by applicable law or agreed to in writing, software
      distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
      WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
      License for the specific language governing permissions and limitations
      under the License.

========================================
Keystone, the OpenStack Identity Service
========================================

Keystone is an OpenStack service that provides API client authentication,
service discovery, and distributed multi-tenant authorization by implementing
`OpenStack's Identity API`_.

This documentation is useful for contributors looking to get involved in our
community, developers writing applications on top of OpenStack, and operators
administering their own OpenStack deployments.

This documentation is generated by the Sphinx toolkit and lives in the `source
tree`_. Also see the :doc:`getting-started/community` page for other ways to interact with the
community.

.. _`OpenStack's Identity API`: https://docs.openstack.org/api-ref/identity/index.html
.. _`source tree`: https://opendev.org/openstack/keystone/src/branch/master/doc/source

Related Projects
~~~~~~~~~~~~~~~~

In addition to creating OpenStack's Identity Service, the Keystone team also
provides a `WSGI middleware`_, an `Authentication library`_ and a `Python
client library`_.

.. _`WSGI middleware`: https://docs.openstack.org/keystonemiddleware/latest
.. _`Authentication library`: https://docs.openstack.org/keystoneauth/latest
.. _`Python client library`: https://docs.openstack.org/python-keystoneclient/latest

Installation Guides
~~~~~~~~~~~~~~~~~~~
.. toctree::
    :maxdepth: 2

    install/index.rst

General Information
~~~~~~~~~~~~~~~~~~~

This section contains general information related to keystone which is relevant
to developers, users and operators. For documentation specific to any of these
three, please see the subsequent sections.

.. toctree::
    :maxdepth: 2

    getting-started/index.rst
    code_documentation.rst
    indices-tables.rst

Contributor Documentation
~~~~~~~~~~~~~~~~~~~~~~~~~

This section contains the documentation needed for developing keystone.

.. toctree::
    :maxdepth: 2

    contributor/index.rst

User Documentation
~~~~~~~~~~~~~~~~~~

This section contains the documentation for end-users of keystone.

.. toctree::
    :maxdepth: 2

    user/index.rst

CLI Documentation
~~~~~~~~~~~~~~~~~

This section details information related to keystone management commands.

.. toctree::
    :maxdepth: 2

    cli/index.rst

Administrator Guides
~~~~~~~~~~~~~~~~~~~~

.. toctree::
    :maxdepth: 3

    admin/index.rst

Configuration Options
~~~~~~~~~~~~~~~~~~~~~

.. toctree::
    :maxdepth: 2

    configuration/index.rst
